"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _Text = _interopRequireDefault(require("../Text"));

var _selectors = require("../../theme/selectors");

var _theme = require("../../utils/theme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var StyledAlert = _styledComponents["default"].div.withConfig({
  displayName: "Alert__StyledAlert",
  componentId: "sc-1emg848-0"
})(["display:flex;background:", ";border-radius:", ";color:", ";margin:", " 0 ", " 0;min-height:1em;opacity:", ";padding:", ";transition:opacity 0.2s linear;a{color:", ";text-decoration:underline;&:hover{text-decoration:none;}}"], (0, _theme.fromAtoms)('Alert', 'type', 'background'), function (props) {
  return props.theme.borderRadius.soft;
}, (0, _theme.fromAtoms)('Alert', 'type', 'color'), (0, _selectors.spacing)('xs'), (0, _selectors.spacing)('xs'), function (props) {
  return props.visible ? '1' : '0';
}, (0, _selectors.spacing)('base'), (0, _theme.fromAtoms)('Alert', 'type', 'color'));

var Content = _styledComponents["default"].div.withConfig({
  displayName: "Alert__Content",
  componentId: "sc-1emg848-1"
})(["flex-grow:1;"]);

var Title = _styledComponents["default"].div.withConfig({
  displayName: "Alert__Title",
  componentId: "sc-1emg848-2"
})(["margin-bottom:", ";"], (0, _selectors.spacing)('xs'));

var StyledText = (0, _styledComponents["default"])(_Text["default"]).withConfig({
  displayName: "Alert__StyledText",
  componentId: "sc-1emg848-3"
})(["color:", ";font-weight:bold;"], function (props) {
  return props.theme.colors.white;
});

var Icon = _styledComponents["default"].i.withConfig({
  displayName: "Alert__Icon",
  componentId: "sc-1emg848-4"
})(["margin-right:", ";"], (0, _selectors.spacing)('xs'));

var CloseIcon = _styledComponents["default"].i.withConfig({
  displayName: "Alert__CloseIcon",
  componentId: "sc-1emg848-5"
})(["cursor:pointer;display:", ";margin-left:", ";"], function (props) {
  return props.visible ? 'block' : 'none';
}, (0, _selectors.spacing)('base'));

var normaliseIconName = function normaliseIconName(name) {
  return name.indexOf('fa-') === -1 ? "fa-".concat(name) : name;
};
/**
 * An alert to let the user know about an action or state.
 * ```javascript
 * import { Alert } from 'weaveworks-ui-components';
 *
 * export default function() {
 *  return (
 *    <div>
 *     <Alert type="warning" visible={true}>
 *       Warning: Hmm, this is not good, but it is not terrible.
 *     </Alert>
 *    </div>
 *   )
 * }
 * ```
 */


function Alert(props) {
  var children = props.children,
      icon = props.icon,
      title = props.title,
      visible = props.visible;

  var onClose = props.onClose,
      otherProps = _objectWithoutProperties(props, ["onClose"]);

  return /*#__PURE__*/_react["default"].createElement(StyledAlert, otherProps, /*#__PURE__*/_react["default"].createElement(Content, null, title && /*#__PURE__*/_react["default"].createElement(Title, null, icon && /*#__PURE__*/_react["default"].createElement(Icon, {
    className: "fa ".concat(normaliseIconName(icon))
  }), /*#__PURE__*/_react["default"].createElement(StyledText, null, title)), children), onClose && /*#__PURE__*/_react["default"].createElement(CloseIcon, {
    visible: visible,
    onClick: onClose,
    className: "fa fa-times"
  }));
}

Alert.propTypes = {
  /**
   * Show an icon for the title
   */
  icon: _propTypes["default"].string,

  /**
   * Callback that runs with the alert is dismissed by clicking the 'X'
   */
  onClose: _propTypes["default"].func,

  /**
   * Show a title for the alert
   */
  title: _propTypes["default"].string,

  /**
   * Set the color scheme to indicate the nature of the alert.
   */
  type: _propTypes["default"].oneOf(['info', 'success', 'warning', 'error']),

  /**
   * Toggle whether the alert is shown
   */
  visible: _propTypes["default"].bool
};
Alert.defaultProps = {
  icon: '',
  onClose: null,
  title: '',
  type: 'info',
  visible: true
};
var _default = Alert;
exports["default"] = _default;